@@ -49,6 +49,7 @@ KEY_FILE=$(grep TLSCertificateKeyFile /etc/ldap/slapd.conf|awk '{print $2}')
 CERT_FILE=$(grep TLSCertificateFile /etc/ldap/slapd.conf|awk '{print $2}')
 CN=$(openssl x509 -subject -noout -in $CERT_FILE|cut -d= -f3)
 CERT_CN=$(echo $CN)
+ALT_DNS=$(openssl x509 -in $CERT_FILE -noout -ext subjectAltName|grep DNS:|tr -d ' ')
 
 EXPIRE=$(openssl x509 -enddate -noout -in $CERT_FILE|cut -d= -f2|date +%s -f -)
 ENDATE=$(openssl x509 -enddate -noout -in $CERT_FILE|cut -d= -f2)
@@ -70,13 +71,14 @@ if [ $EXPIRE -lt $LIMIT ]; then
     mv -f --backup=numbered pki/reqs/$CERT_CN.req oldCERTS
     mv -f --backup=numbered $CERT_FILE oldCERTS
     mv -f --backup=numbered $KEY_FILE  oldCERTS
-    ./easyrsa --batch --auto-san --days=$DAYS build-serverClient-full $CERT_CN nopass
+    ./easyrsa --batch --san=$ALT_DNS --days=$DAYS build-serverClient-full $CERT_CN nopass
     cp -a pki/issued/$CERT_CN.crt $CERT_FILE
     cp -a pki/private/$CERT_CN.key $KEY_FILE
     chmod g+r $KEY_FILE
     chgrp ssl-cert $KEY_FILE
     chmod +r $CERT_FILE
     systemctl restart slapd.service
+    systemctl restart apache2.service
 else
     echo Certificate still valid, expiring $ENDATE
 fi
