@@ -29,6 +29,6 @@ klist -k|awk '{print $2}'|sort|uniq -c|sort -n|tail|while read NUM KEY;  do
 #    echo NUM=$NUM
 #    echo KEY=$KEY
     if [ $NUM -gt $THRESHOLD ]; then
-	kadmin.local ktremove $KEY old 
+	/usr/sbin/kadmin.local ktremove $KEY old
     fi
 done 
